@@ -49,7 +49,7 @@ QVariant KCalllistModel::data(const QModelIndex & index, int role) const {
 
 	switch (index.column()) {
 		case 1:
-			return QVariant(toUnicode((ce->date+" "+ce->time)));
+			return QVariant(toUnicode((ce->date + ' ' + ce->time)));
 			break;
 		case 2:
 			if (ce->remoteName.size() == 0)
@@ -156,7 +156,18 @@ void KCalllistModel::check() {
 	}
 }
 
-std::string KCalllistModel::number(const QModelIndex &i) const {
-	fritz::CallEntry *ce = calllist->RetrieveEntry(fritz::CallEntry::ALL,i.row());
-	return ce->remoteNumber;
+std::string KCalllistModel::number(const QModelIndex &index) const {
+	if (index.isValid()) {
+		fritz::CallEntry *ce = calllist->RetrieveEntry(fritz::CallEntry::ALL, index.row());
+		return ce->remoteNumber;
+	} else
+		return "";
+}
+
+std::string KCalllistModel::name(const QModelIndex &index) const {
+	if (index.isValid()) {
+		fritz::CallEntry *ce = calllist->RetrieveEntry(fritz::CallEntry::ALL, index.row());
+		return ce->remoteName;
+	} else
+		return "";
 }
