@@ -19,8 +19,8 @@
  *
  */
 
-#ifndef KFONBOOKMODEL_H_
-#define KFONBOOKMODEL_H_
+#ifndef KFONBOOKMODEL_H
+#define KFONBOOKMODEL_H
 
 #include <FonbookManager.h>
 
@@ -37,7 +37,8 @@ public:
                                 int role = Qt::DisplayRole) const;
     virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
     virtual bool setData(const QModelIndex & index, const QVariant & value, int role = Qt::EditRole);
-    void setDefaultType(const QModelIndex &index);
+    void setDefault(const QModelIndex &index);
+    void setType(const QModelIndex &index, fritz::FonbookEntry::eType type);
     virtual Qt::ItemFlags flags(const QModelIndex & index) const;
     virtual void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);
     static QString getTypeName(const fritz::FonbookEntry::eType type);
