@@ -32,17 +32,21 @@
 
 #include "KSettings.h"
 
-static const char *VERSION        = "0.0.7";
+static const char *VERSION        = "0.0.8";
 
 KFritz::KFritz(KFritzWindow *mainWindow, KAboutData *aboutData)
 :KSystemTrayIcon("modem", mainWindow) {
 	this->aboutData = aboutData;
 	this->mainWindow = mainWindow;
+	connect(this, SIGNAL(quitSelected()), mainWindow, SLOT(quit()));
 }
 
 KFritz::~KFritz() {
 }
 
+bool KFritz::parentWidgetTrayClose() const {
+	return true;
+}
 
 int main (int argc, char *argv[]) {
 	// init KDE-stuff
@@ -87,5 +91,6 @@ int main (int argc, char *argv[]) {
 	KFritz *trayIcon 	    = new KFritz(&mainWindow, &aboutData);
 	trayIcon->show();
 	int ret = app.exec();
+	fritz::Config::Shutdown();
 	return ret;
 }
