@@ -19,15 +19,17 @@
  *
  */
 
-#ifndef KFRITZBOX_H_
-#define KFRITZBOX_H_
+#ifndef KFRITZBOX_H
+#define KFRITZBOX_H
 
 #include <QObject>
 #include <KSystemTrayIcon>
 #include <KAboutData>
-#include "KFritzWindow.h"
+
 #include <Listener.h>
 
+#include "KFritzWindow.h"
+
 class KFritz : public KSystemTrayIcon
 {
 	Q_OBJECT
@@ -35,6 +37,7 @@ class KFritz : public KSystemTrayIcon
 public:
 	KFritz(KFritzWindow *mainWindow, KAboutData *aboutData);
 	virtual ~KFritz();
+	bool parentWidgetTrayClose() const;
 private:
 	KAboutData 	 *aboutData;
 	KFritzWindow *mainWindow;
