@@ -22,11 +22,11 @@
 
 #include <KApplication>
 #include <KAction>
+#include <KSelectAction>
 #include <KActionCollection>
 #include <KLocale>
 #include <KAboutData>
 #include <KFilterProxySearchLine>
-#include <KFindDialog>
 #include <KStandardAction>
 #include <KService>
 #include <KStatusBar>
@@ -113,6 +113,8 @@ KFritzWindow::KFritzWindow()
 
 	setupActions();
 
+	inputCodec  = QTextCodec::codecForName(fritz::CharSetConv::SystemCharacterTable() ? fritz::CharSetConv::SystemCharacterTable() : "UTF-8");
+
 	setupGUI();
 	KXmlGuiWindow::stateChanged("NoEdit");
 
@@ -125,23 +127,23 @@ KFritzWindow::~KFritzWindow()
 	// move logging to console
 	fritz::Config::SetupLogging(&std::clog, &std::cout, &std::cerr);
 
-	fritz::FonbookManager::DeleteFonbookManager();
-	fritz::CallList::DeleteCallList();
-
 	delete libFritzInit;
 }
 
+QString KFritzWindow::toUnicode(const std::string string) const {
+	return inputCodec->toUnicode(string.c_str());
+}
+
 void KFritzWindow::HandleCall(bool outgoing, int connId __attribute__((unused)), std::string remoteNumber, std::string remoteName, fritz::FonbookEntry::eType type, std::string localParty __attribute__((unused)), std::string medium __attribute__((unused)), std::string mediumName)
 {
-	QTextCodec *inputCodec  = QTextCodec::codecForName(fritz::CharSetConv::SystemCharacterTable() ? fritz::CharSetConv::SystemCharacterTable() : "UTF-8");
-	QString qRemoteName    = inputCodec->toUnicode(remoteName.c_str());
+	QString qRemoteName    = toUnicode(remoteName);
 	QString qTypeName      = KFonbookModel::getTypeName(type);
 
 	if (qTypeName.size() > 0)
-		qRemoteName += " (" + qTypeName + ")";
+		qRemoteName += " (" + qTypeName + ')';
 
-	//QString qLocalParty = inputCodec->toUnicode(localParty.c_str());
-	QString qMediumName    = inputCodec->toUnicode(mediumName.c_str());
+	//QString qLocalParty = toUnicode(localParty);
+	QString qMediumName    = toUnicode(mediumName);
 	QString qMessage;
 	if (outgoing)
 		qMessage=i18n("Outgoing call to <b>%1</b><br/>using %2",   qRemoteName.size() ? qRemoteName : remoteNumber.c_str(),                                    qMediumName);
@@ -175,7 +177,7 @@ void KFritzWindow::slotNotification(QString event, QString qMessage, bool persis
 	notification = new KNotification (event, this, persistent ? KNotification::Persistent : KNotification::CloseOnTimeout);
 	KIcon ico(event == "incomingCall" ? "incoming-call" :
 			  event == "outgoingCall" ? "outgoing-call" :
-					                    "internet-telephony");
+					                    "internet-telephony"); //krazy:exclude=spelling
 	notification->setTitle(programName);
 	notification->setPixmap(ico.pixmap(64, 64));
 	notification->setText(qMessage);
@@ -270,7 +272,7 @@ void KFritzWindow::setupActions() {
 
 	KAction *aDialNumber = new KAction(this);
 	aDialNumber->setText(i18n("Dial number"));
-	aDialNumber->setIcon(KIcon("internet-telephony"));
+	aDialNumber->setIcon(KIcon("internet-telephony")); //krazy:exclude=spelling
 	actionCollection()->addAction("dialNumber", aDialNumber);
 	connect(aDialNumber, SIGNAL(triggered(bool)), this, SLOT(dialNumber()));
 
@@ -284,7 +286,17 @@ void KFritzWindow::setupActions() {
 	aSetDefaultType->setText(i18n("Set as default"));
 	aSetDefaultType->setIcon(KIcon("favorites"));
 	actionCollection()->addAction("setDefaultType", aSetDefaultType);
-	connect(aSetDefaultType, SIGNAL(triggered(bool)), this, SLOT(setDefaultType()));
+	connect(aSetDefaultType, SIGNAL(triggered(bool)), this, SLOT(setDefault()));
+
+	KSelectAction *aSetType = new KSelectAction(this);
+	aSetType->setText(i18n("Set type"));
+	for (size_t p = fritz::FonbookEntry::TYPE_HOME; p < fritz::FonbookEntry::TYPES_COUNT; p++) {
+		aSetType->addAction(KFonbookModel::getTypeName((fritz::FonbookEntry::eType) p));
+	}
+
+	//TODO: icon?
+	actionCollection()->addAction("setType", aSetType);
+	connect(aSetType, SIGNAL(triggered(int)), this, SLOT(setType(int)));
 
 	//TODO: Set Important
 
@@ -295,7 +307,7 @@ void KFritzWindow::setupActions() {
 	connect(aReload, SIGNAL(triggered(bool)), this, SLOT(reload()));
 
 	KAction *aReconnectISP = new KAction(this);
-	aReconnectISP->setText(i18n("Reconnect to internet"));
+	aReconnectISP->setText(i18n("Reconnect to the Internet"));
 	aReconnectISP->setIcon(KIcon("network-workgroup"));
 	actionCollection()->addAction("reconnectISP", aReconnectISP);
 	connect(aReconnectISP, SIGNAL(triggered(bool)), this, SLOT(reconnectISP()));
@@ -321,7 +333,7 @@ void KFritzWindow::setupActions() {
 	connect(aDeleteEntry, SIGNAL(triggered(bool)), this, SLOT(deleteEntry()));
 
 	KAction *aResolveNumber = new KAction(this);
-	aResolveNumber->setText(i18n("Resolve number"));
+	aResolveNumber->setText(i18n("Look up number in phone books"));
 	actionCollection()->addAction("resolveNumber", aResolveNumber);
 	connect(aResolveNumber, SIGNAL(triggered(bool)), this, SLOT(resolveNumber()));
 
@@ -336,7 +348,7 @@ void KFritzWindow::setupActions() {
 	KStandardAction::cut(this, SLOT(cutEntry()), actionCollection());
 	KStandardAction::copy(this, SLOT(copyEntry()), actionCollection());
 	KStandardAction::paste(this, SLOT(pasteEntry()), actionCollection());
-	KStandardAction::quit(kapp, SLOT(quit()), actionCollection());
+	KStandardAction::quit(this, SLOT(quit()), actionCollection());
 
 }
 
@@ -455,8 +467,13 @@ void KFritzWindow::updateMainWidgets(bool b)
     		treeFonbook->addAction(actionCollection()->action("separator2"));
     		treeFonbook->addAction(actionCollection()->action("dialNumber"));
     		treeFonbook->addAction(actionCollection()->action("copyNumber"));
-    		treeFonbook->addAction(actionCollection()->action("setDefaultType"));
+    		treeFonbook->addAction(actionCollection()->action("setDefaultType")); //TODO: misleading name 'type'
+    		treeFonbook->addAction(actionCollection()->action("setType"));
     		treeFonbook->setContextMenuPolicy(Qt::ActionsContextMenu);
+    		connect(treeFonbook->selectionModel(), SIGNAL(currentChanged(const QModelIndex&, const QModelIndex&)), this, SLOT(updateFonbookContextMenu(const QModelIndex&, const QModelIndex&)));
+    		//TODO: also reaction on data changes (dataChanged on model)
+
+    		//TODO: TAB-order by row (not by column) reimplement moveCursor( )
 
     		ContainerWidget *fonbookContainer = new ContainerWidget(this, treeFonbook, modelFonbook);
     		new QVBoxLayout(fonbookContainer);
@@ -469,22 +486,32 @@ void KFritzWindow::updateMainWidgets(bool b)
     connect(tabWidget, SIGNAL(currentChanged(int)), this, SLOT(updateActionProperties(int)));
     connect(tabWidget, SIGNAL(currentChanged(int)), statusBar(), SLOT(clearMessage()));
     updateActionProperties(tabWidget->currentIndex());
+    connect(treeCallList->selectionModel(), SIGNAL(currentRowChanged(const QModelIndex&, const QModelIndex&)), this, SLOT(updateCallListContextMenu(const QModelIndex&, const QModelIndex&)));
 }
 
-void KFritzWindow::find() {
-	QStringList findStrings;
-	KFindDialog dlg(this, 0, findStrings, true, false);
-	if (dlg.exec() != QDialog::Accepted)
-		return;
-
-}
-
-void KFritzWindow::findNext() {
-
-}
-
-void KFritzWindow::findPrev() {
+//TODO: quit using systray
+void KFritzWindow::quit() {
+	// check for pending changes
+	fritz::FonbookManager *fm = fritz::FonbookManager::GetFonbookManager();
+	std::string first = fm->GetTechId();
+	if (first.length()) {
+		do {
+			if (fm->isModified()) {
+				switch (KMessageBox::warningYesNoCancel( this, i18n("Save changes to %1?", fm->GetTitle().c_str()))) {
+				case KMessageBox::Yes :
+					fm->Save();
+					break;
+				case KMessageBox::No :
+					break;
+				default: // cancel
+					return;
+				}
+			}
+			fm->NextFonbook();
+		} while (first != fm->GetTechId());
+	}
 
+	QApplication::quit();
 }
 
 void KFritzWindow::showMainWindow() {
@@ -528,27 +555,38 @@ void KFritzWindow::copyNumberToClipboard() {
 	KApplication::kApplication()->clipboard()->setText(getCurrentNumber().c_str());
 }
 
-void KFritzWindow::setDefaultType() {
+void KFritzWindow::setDefault() {
 	ContainerWidget *container = static_cast<ContainerWidget *>(tabWidget->currentWidget());
 	QAdaptTreeView *treeView = container->getTreeView();
 	if (container->isFonbook()) {
-		container->getFonbookModel()->setDefaultType(treeView->currentIndex());
+		container->getFonbookModel()->setDefault(treeView->currentIndex());
+	}
+}
+
+void KFritzWindow::setType(int index) {
+	ContainerWidget *container = static_cast<ContainerWidget *>(tabWidget->currentWidget());
+	QAdaptTreeView *treeView = container->getTreeView();
+	if (container->isFonbook()) {
+		container->getFonbookModel()->setType(treeView->currentIndex(), (fritz::FonbookEntry::eType)(index+1)); //TODO: improve mapping index->type
 	}
 }
 
 void KFritzWindow::reload() {
-	updateConfiguration();
+	updateConfiguration();  //TODO: pending changes are lost without warning
 }
 
 void KFritzWindow::reconnectISP() {
 	fritz::FritzClient fc;
-	fc.reconnectISP();
-	KMessageBox::information(this, i18n("Reconnect initiated."));
+	if (fc.reconnectISP())
+		KMessageBox::information(this, i18n("Reconnect initiated."));
+	else
+		KMessageBox::error(this, i18n("Reconnect failed."));
 }
 
 void KFritzWindow::getIP() {
 	fritz::FritzClient fc;
-	KMessageBox::information(this, i18n("Current IP address is: %1", fc.getCurrentIP().c_str()));
+	std::string ip = fc.getCurrentIP();
+	KMessageBox::information(this, i18n("Current IP address is: %1", ip.size() ? ip.c_str() : i18n("unknown")));
 }
 
 void KFritzWindow::addEntry(fritz::FonbookEntry *fe) {
@@ -598,7 +636,7 @@ void KFritzWindow::copyEntry() {
 		KCalllistProxyModel *model = container->getCalllistModel();
 		const fritz::CallEntry *ce = model->retrieveCallEntry(treeView->currentIndex());
 		fritz::FonbookEntry fe(ce->remoteName);
-		fe.AddNumber(ce->remoteNumber, fritz::FonbookEntry::TYPE_NONE);
+		fe.AddNumber(0, ce->remoteNumber, fritz::FonbookEntry::TYPE_NONE);
 		QMimeData* mimeData = new MimeFonbookEntry(fe);
 		QApplication::clipboard()->setMimeData(mimeData);
 	}
@@ -618,17 +656,19 @@ void KFritzWindow::pasteEntry() {
 
 void KFritzWindow::resolveNumber() {
 	ContainerWidget *container = static_cast<ContainerWidget *>(tabWidget->currentWidget());
-	QAdaptTreeView *treeView = container->getTreeView();
 	if (container->isCalllist()) {
 		std::string currentNumber = getCurrentNumber();
 		fritz::Fonbook::sResolveResult result = fritz::FonbookManager::GetFonbook()->ResolveToName(currentNumber);
 		if (!result.name.compare(currentNumber)) {
-			statusBar()->showMessage(i18n("%1 did not resolve.", QString(currentNumber.c_str())), 0);
+			statusBar()->showMessage(i18n("%1 did not resolve.", toUnicode(currentNumber)), 0);
 		} else {
-			fritz::CallEntry *entry = container->getCalllistModel()->retrieveCallEntry(treeView->currentIndex());
-			entry->remoteName = result.name;
-			//TODO: change all calllist entries with this number
-		    statusBar()->showMessage(i18n("%1 resolves to \"%2\".", QString(currentNumber.c_str()), QString(result.name.c_str())), 0);
+			KCalllistProxyModel *model = container->getCalllistModel();
+			for (int pos = 0; pos < model->rowCount(QModelIndex()); pos++) {
+				fritz::CallEntry *entry = model->retrieveCallEntry(model->index(pos, 0, QModelIndex()));
+				if (entry->MatchesRemoteNumber(currentNumber))
+					entry->remoteName = result.name;
+			}
+			statusBar()->showMessage(i18n("%1 resolves to \"%2\".", toUnicode(currentNumber), toUnicode(result.name), 0));
 		}
 	}
 }
@@ -642,6 +682,35 @@ void KFritzWindow::updateActionProperties(int tabIndex __attribute__((unused)))
 	}
 }
 
+void KFritzWindow::updateCallListContextMenu(const QModelIndex &current, const QModelIndex &previous __attribute__((unused))) {
+	ContainerWidget *container = static_cast<ContainerWidget *>(tabWidget->currentWidget());
+	if (container->isCalllist()) {
+		KCalllistProxyModel *model = container->getCalllistModel();
+		bool canResolve = (model->name(current).compare(model->number(current)) == 0);
+		actionCollection()->action("resolveNumber")->setEnabled(canResolve);
+	}
+}
+
+void KFritzWindow::updateFonbookContextMenu(const QModelIndex &current, const QModelIndex &previous __attribute__((unused))) {
+	ContainerWidget *container = static_cast<ContainerWidget *>(tabWidget->currentWidget());
+	KSelectAction *action = static_cast<KSelectAction *>(actionCollection()->action("setType"));
+	if (container->isFonbook()) {
+		if (current.column() > 0 && current.column() <= fritz::FonbookEntry::MAX_NUMBERS) {
+			KFonbookModel *model = container->getFonbookModel();
+			const fritz::FonbookEntry *entry = model->retrieveFonbookEntry(current);
+			fritz::FonbookEntry::eType type = entry->GetType(current.column()-1);
+			if (entry->GetNumber(current.column()-1).size()) {
+				action->setCurrentItem(type-1);
+				action->setEnabled(true);
+			} else {
+				action->setEnabled(false);
+			}
+		} else {
+			action->setEnabled(false);
+		}
+	}
+}
+
 void KFritzWindow::setProgressIndicator(QString message) {
 	if (!message.length()) {
 		if (progressIndicator) {
