@@ -19,8 +19,8 @@
  *
  */
 
-#ifndef KFRITZBOXWINDOW_H_
-#define KFRITZBOXWINDOW_H_
+#ifndef KFRITZWINDOW_H
+#define KFRITZWINDOW_H
 
 #include <KXmlGuiWindow>
 #include <KTextEdit>
@@ -60,6 +60,8 @@ private:
 	QAdaptTreeView *treeCallList;
 	QIndicate::Indicator *missedCallsIndicator;
 	QWidget *progressIndicator;
+	QTextCodec *inputCodec;
+	QString toUnicode(const std::string string) const;
 	void saveToWallet(KWallet::Wallet *wallet);
 	bool showPasswordDialog(QString &password, bool offerSaving = false);
 	void setupActions();
@@ -76,9 +78,7 @@ public  Q_SLOTS:
     void updateMissedCallsIndicator();
     void showStatusbarBoxBusy(bool b);
     void updateMainWidgets(bool b);
-    void find();
-    void findNext();
-    void findPrev();
+    void quit();
 public:
     KFritzWindow();
     virtual ~KFritzWindow();
@@ -95,7 +95,8 @@ public Q_SLOTS:
 	void showLog();
     void dialNumber();
     void copyNumberToClipboard();
-    void setDefaultType();
+    void setDefault();
+    void setType(int index);
     void reload();
     void reconnectISP();
     void getIP();
@@ -106,6 +107,8 @@ public Q_SLOTS:
     void pasteEntry();
     void resolveNumber();
     void updateActionProperties(int tabIndex);
+    void updateCallListContextMenu(const QModelIndex &current, const QModelIndex &previous);
+    void updateFonbookContextMenu(const QModelIndex &current, const QModelIndex &previous);
 
 };
 
