@@ -21,8 +21,6 @@
 
 #include "LibFritzInit.h"
 
-#include <FonbookManager.h>
-#include <Config.h>
 #include <CallList.h>
 #include <KGlobal>
 #include <KCmdLineArgs>
@@ -32,6 +30,9 @@
 #include <KAboutData>
 #include <KStandardDirs>
 
+#include <FonbookManager.h>
+#include <Config.h>
+
 #include "KSettings.h"
 #include "Log.h"
 
@@ -42,7 +43,6 @@ LibFritzInit::LibFritzInit(QString password, fritz::EventHandler *eventHandler)
 }
 
 LibFritzInit::~LibFritzInit() {
-	fritz::Listener::DeleteListener();
 }
 
 void LibFritzInit::run() {
@@ -71,7 +71,7 @@ void LibFritzInit::run() {
 		KSettings::self()->writeConfig();
 	}
 
-	fritz::Config::SetupConfigDir(KStandardDirs::locateLocal("data", KGlobal::mainComponent().aboutData()->appName()+"/").toStdString());
+	fritz::Config::SetupConfigDir(KStandardDirs::locateLocal("data", KGlobal::mainComponent().aboutData()->appName()+'/').toStdString());
 
 	std::vector<std::string> vMsn;
 	QStringList msnList = KSettings::mSNFilter();
@@ -85,7 +85,7 @@ void LibFritzInit::run() {
 	QStringList phonebookList = KSettings::phonebookList();
 	while (phonebookList.count())
 		vFonbook.push_back(phonebookList.takeFirst().toStdString());
-	fritz::FonbookManager::CreateFonbookManager(vFonbook, "");
+	fritz::FonbookManager::CreateFonbookManager(vFonbook, "", false);
 
 	fritz::CallList::CreateCallList();
 
