@@ -20,12 +20,14 @@
  */
 
 #include "CallList.h"
+
+#include <algorithm>
+#include <cstdlib>
+#include <time.h>
+
 #include "Tools.h"
 #include "Config.h"
 #include "FritzClient.h"
-#include <time.h>
-#include <stdlib.h>
-#include <algorithm>
 
 namespace fritz{
 
@@ -118,8 +120,12 @@ CallList::~CallList()
 }
 
 void CallList::run() {
-	FritzClient fc;
-	std::string msg = fc.RequestCallList();
+	DBG("CallList thread started");
+
+	FritzClient *fc = new FritzClient();
+	std::string msg = fc->RequestCallList();
+	delete fc;
+
 	std::vector<CallEntry> callList;
 	// parse answer
 	size_t pos = 0;
@@ -161,9 +167,6 @@ void CallList::run() {
 		// put the number into the name field if name is not available
 		if (ce.remoteName.size() == 0)
 			ce.remoteName = ce.remoteNumber;
-		// if also no number is available, put "unknown" into the name field
-		if (ce.remoteName.size() == 0)
-			ce.remoteName = I18N_NOOP("unknown");
 
 		//       01234567        01234
 		// date: dd.mm.yy, time: hh:mm
@@ -196,7 +199,7 @@ void CallList::run() {
 	lastCall = 0;
 	lastMissedCall = 0;
 
-	for(std::vector<CallEntry>::iterator it = callListAll.begin(); it < callListAll.end(); it++) {
+	for(std::vector<CallEntry>::iterator it = callListAll.begin(); it < callListAll.end(); ++it) {
 		CallEntry ce = *it;
 
 		if (lastCall < ce.timestamp)
@@ -220,7 +223,7 @@ void CallList::run() {
 		}
 	}
 	valid = true;
-	exit();
+	DBG("CallList thread ended");
 }
 
 CallEntry *CallList::RetrieveEntry(CallEntry::eCallType type, size_t id) {
@@ -289,5 +292,9 @@ bool CallEntry::MatchesFilter() {
 	}
 }
 
+bool CallEntry::MatchesRemoteNumber(std::string number) {
+	return (Tools::NormalizeNumber(number).compare(Tools::NormalizeNumber(remoteNumber)) == 0);
+}
+
 }
 
