@@ -19,11 +19,13 @@
  *
  */
 
+#include "FritzFonbook.h"
+
 #include <algorithm>
 #include <sstream>
-#include "FritzFonbook.h"
-#include "FritzClient.h"
+
 #include "Config.h"
+#include "FritzClient.h"
 
 namespace fritz {
 
@@ -47,11 +49,13 @@ bool FritzFonbook::Initialize() {
 }
 
 void FritzFonbook::run() {
+	DBG("FritzFonbook thread started");
 	setInitialized(false);
 	Clear();
 
-	FritzClient fc;
-	std::string msg = fc.RequestFonbook();
+	FritzClient *fc = new FritzClient();
+	std::string msg = fc->RequestFonbook();
+	delete fc;
 
 	if (msg.find("<?xml") == std::string::npos)
 		ParseHtmlFonbook(&msg);
@@ -63,7 +67,7 @@ void FritzFonbook::run() {
 	setInitialized(true);
 
 	Sort(FonbookEntry::ELEM_NAME, true);
-	exit();
+	DBG("FritzFonbook thread ended");
 }
 
 void FritzFonbook::ParseHtmlFonbook(std::string *msg) {
@@ -102,7 +106,7 @@ void FritzFonbook::ParseHtmlFonbook(std::string *msg) {
 		std::string numberPart = msgConv.substr(numberStart, numberStop - numberStart+1);
 		if (namePart2.length() && numberPart.length()) {
 			FonbookEntry fe(namePart2, false); // TODO: important is not parsed here
-			fe.AddNumber(numberPart, FonbookEntry::TYPE_NONE);
+			fe.AddNumber(0, numberPart, FonbookEntry::TYPE_NONE);
 			AddFonbookEntry(fe);
 			//DBG("(%s / %s)", fe.number.c_str(), fe.name.c_str());
 		}
@@ -123,6 +127,7 @@ void FritzFonbook::ParseHtmlFonbook(std::string *msg) {
 		FonbookEntry fe(namePartConv, false); // TODO: important is not parsed here
 
 		size_t posInner = pos;
+		size_t numberCount = 0;
 		// iterate over all tagNumbers between two tagNames
 		while ((posInner = msgConv.find(tagNumber, ++posInner)) != std::string::npos && posInner < msgConv.find(tagName, pos+1)) {
 			int typeStart     = posInner + 9;
@@ -140,14 +145,13 @@ void FritzFonbook::ParseHtmlFonbook(std::string *msg) {
 				type = FonbookEntry::TYPE_WORK;
 
 			if (namePartConv.length() && numberPart.length()) {
-				fe.AddNumber(numberPart, type); // TODO: quickdial, vanity and priority not parsed here
+				fe.AddNumber(numberCount++, numberPart, type); // TODO: quickdial, vanity and priority not parsed here
 				//DBG("(%s / %s / %i)", fe.number.c_str(), fe.name.c_str(), fe.type);
 			}
 			count++;
 		}
 		AddFonbookEntry(fe);
 	}
-	INF("read " << GetFonbookSize() << " entries.");
 }
 
 void FritzFonbook::Reload() {
