@@ -19,23 +19,25 @@
  *
  */
 
+#ifndef FRITZFONBOOK_H
+#define FRITZFONBOOK_H
 
-#ifndef FRITZFONBUCH_H_
-#define FRITZFONBUCH_H_
+#include <cc++/thread.h>
 
-#include <PThread++.h>
-#include "Fonbook.h"
+#include "XmlFonbook.h"
 
 namespace fritz{
 
-class FritzFonbook : public pthread::PThread, public Fonbook {
+class FritzFonbook : public ost::Thread, public XmlFonbook {
 			friend class FonbookManager;
 private:
 	FritzFonbook();
+	void ParseHtmlFonbook(std::string *msg);
+	virtual void Write();
 public:
-	~FritzFonbook();
+	virtual ~FritzFonbook();
 	bool Initialize();
-	void Action();
+	void run();
 	void Reload();
 };
 
