@@ -19,13 +19,15 @@
  *
  */
 
-#include <string.h>
-#include <algorithm>
-#include <iostream>
-#include <fstream>
-#include "Tools.h"
 #include "LocalFonbook.h"
+
+#include <algorithm>
+#include <fstream>
+#include <iostream>
+#include <string>
+
 #include "Config.h"
+#include "Tools.h"
 
 namespace fritz {
 
@@ -161,14 +163,14 @@ void LocalFonbook::ParseCsvFonbook(std::string filePath) {
 				for (size_t feNr = 0; feNr < GetFonbookSize(); feNr++)
 					if (RetrieveFonbookEntry(feNr)->GetName() == name) {
 						FonbookEntry fe(RetrieveFonbookEntry(feNr));
-						fe.AddNumber(number, type); //TODO: quickdial, vanity and priority not supported here
+						fe.AddNumber(type, number, type); //TODO: quickdial, vanity and priority not supported here
 						ChangeFonbookEntry(feNr, fe);
 						feExists = true;
 					}
 				// add to new fe
 				if (!feExists) {
 					FonbookEntry fe(name, false); //TODO: important not supported here
-					fe.AddNumber(number, type);
+					fe.AddNumber(type, number, type);
 					AddFonbookEntry(fe);
 				}
 			}
@@ -176,7 +178,6 @@ void LocalFonbook::ParseCsvFonbook(std::string filePath) {
 				ERR("parse error at " << s);
 			}
 		}
-		INF("read " << GetFonbookSize() << " entries.");
 		Sort(FonbookEntry::ELEM_NAME, true);
 		fclose(f);
 	}
