@@ -19,25 +19,23 @@
  *
  */
 
-#ifndef LOCALFONBOOK_H_
-#define LOCALFONBOOK_H_
+#ifndef LOCALFONBOOK_H
+#define LOCALFONBOOK_H
 
-#include "Fonbook.h"
-#include <vector>
+#include "XmlFonbook.h"
 
-namespace fritz{
+namespace fritz {
 
-class LocalFonbook : public Fonbook {
+class LocalFonbook : public XmlFonbook {
 	friend class FonbookManager;
 private:
 	char* filePath;
 	LocalFonbook();
-	void SaveToFile();
+	void ParseCsvFonbook(std::string filePath);
+	virtual void Write();
 public:
-	virtual ~LocalFonbook();
 	bool Initialize();
 	void Reload();
-	virtual bool AddFonbookEntry(FonbookEntry fe);
 };
 
 }
