@@ -19,11 +19,11 @@
  *
  */
 
-
-#ifndef NUMMERZOEKER_H_
-#define NUMMERZOEKER_H_
+#ifndef NUMMERZOEKER_H
+#define NUMMERZOEKER_H
 
 #include <string>
+
 #include "Fonbook.h"
 
 namespace fritz{
@@ -56,7 +56,7 @@ public:
 	/**
 	 * Returns a specific telephonebook entry.
 	 * @param id unique identifier of the requested entry
-	 * @return the entry with key id or NULL, if unsuccesful
+	 * @return the entry with key id or NULL, if unsuccessful
 	 */
 	virtual const FonbookEntry *RetrieveFonbookEntry(size_t id __attribute__((unused))) const { return NULL; }
 
